from .julia_import import jl, DistanceTransforms
from .transform import transform
from .transform_cuda import transform_cuda

__all__ = [
    "jl",
    "DistanceTransforms",
    "transform",
    "transform_cuda"
]



import juliacall as jc
from juliacall import Main as jl

jl.seval("using Pkg; Pkg.status()")
jl.seval("using PythonCall")
jl.seval("using DLPack")
jl.seval("using CUDA")
jl.seval("using DistanceTransforms")

PythonCall = jl.PythonCall
DLPack = jl.DLPack
DistanceTransforms = jl.DistanceTransforms



import numpy as np
from .julia_import import jl, DistanceTransforms

def transform(arr):
    arr_jl = jl.convert(jl.Array, arr)
    result_jl = DistanceTransforms.transform(DistanceTransforms.boolean_indicator(arr_jl))
    return np.asarray(result_jl, dtype=arr.dtype)
    


import torch
from .julia_import import jc, PythonCall, DLPack, DistanceTransforms

def transform_cuda(tensor):
    tensor_jl = DLPack.from_dlpack(jc.convert(PythonCall.Py, tensor))
    result_jl = DistanceTransforms.transform(DistanceTransforms.boolean_indicator(tensor_jl))
    return DLPack.share(result_jl, torch.from_dlpack)
    